==> e2e_cli-0.9.3.3.tar.gz: e2e_cli-0.9.3.3/e2e_cli/core/alias_service.py <==
import json
import os
import platform

from e2e_cli.core.py_manager import Py_version_manager

class AliasServices:
    def __init__(self, alias):
        self.alias = alias

    def get_api_credentials(self):
        file= os.path.expanduser("~") + '/.E2E_CLI/config.json'
        file_reference = open(file, "r")
        config_file_object = json.loads(file_reference.read())
        if self.alias in config_file_object:
            return {"api_credentials": config_file_object[self.alias],
                    "message": "Valid alias"}
        else:
            return {"message": "Invalid alias provided"}

def system_file():
    if platform.system() == "Windows":  
                return os.path.expanduser("~") + '\.E2E_CLI\config.json'
    elif platform.system() == "Linux" or platform.system() == "Mac":  
                return os.path.expanduser("~") + '/.E2E_CLI/config.json'


def get_user_cred(name, x=0):
    
    file= system_file()

    # try :
    # Opening JSON file
    f = open(file)
    
    # returns JSON object as a dictionary
    data = json.load(f)

    if(name=="all" and x==1):
                return data.keys()
    
    # Closing file
    f.close()

    # except Exception as e:
    #     ErrorLogs(traceback.format_list(traceback.extract_stack()), e, name).add_to_error_logs()
    #     # if 'No such file or directory:' in str(e):
    #     return None


    if(name in data):
        return[ data[name]['api_auth_token'], data[name]['api_key'] ]
    elif x==2:
        return None
    else:
        Py_version_manager.py_print("the given alias/credential doesn't exist")
        return None

==> e2e_cli-0.9.3.5.1.tar.gz: e2e_cli-0.9.3.5.1/e2e_cli/core/alias_service.py <==
import json
import os
import platform

from e2e_cli.core.py_manager import Py_version_manager

class AliasServices:
    def __init__(self, alias):
        self.alias = alias

    def get_api_credentials(self):
        file= os.path.expanduser("~") + '/.E2E_CLI/config.json'
        file_reference = open(file, "r")
        config_file_object = json.loads(file_reference.read())
        if self.alias in config_file_object:
            return {"api_credentials": config_file_object[self.alias],
                    "message": "Valid alias"}
        else:
            return {"message": "Invalid alias provided"}

def system_file():
    if platform.system() == "Windows":  
                return os.path.expanduser("~") + '\.E2E_CLI\config.json'
    elif platform.system() == "Linux" or platform.system() == "Darwin":  
                return os.path.expanduser("~") + '/.E2E_CLI/config.json'


def get_user_cred(name, x=0):
    
    file= system_file()

    # try :
    # Opening JSON file
    f = open(file)
    
    # returns JSON object as a dictionary
    data = json.load(f)

    if(name=="all" and x==1):
                return data.keys()
    
    # Closing file
    f.close()

    # except Exception as e:
    #     ErrorLogs(traceback.format_list(traceback.extract_stack()), e, name).add_to_error_logs()
    #     # if 'No such file or directory:' in str(e):
    #     return None


    if(name in data):
        return[ data[name]['api_auth_token'], data[name]['api_key'] ]
    elif x==2:
        return None
    else:
        Py_version_manager.py_print("the given alias/credential doesn't exist")
        return None
